<!-- Image -->
<div align="center">
    <img src="https://raw.githubusercontent.com/pyrustic/misc/master/media/jupitest-screenshot.png" alt="Figure">
    <p align="center">
    Jupitest
    </p>
</div>

<!-- Intro Text -->
# Jupitest
<b> Graphical test runner built with Pyrustic Framework </b>

This project is part of the [Pyrustic Ecosystem](https://pyrustic.github.io).

<!-- Image -->
<div align="center">
    <img src="https://raw.githubusercontent.com/pyrustic/misc/master/media/jupitest.gif" alt="Figure" width="650">
    <p align="center">
    <b> Jupitest in action </b>
    </p>
</div>


`Jupitest` uses the dark theme [cyberpunk-theme](https://github.com/pyrustic/cyberpunk-theme) and the tk-compatible multithreading library [threadom](https://github.com/pyrustic/threadom).


## Installation
```bash
pip install jupitest
```